@@ -33,7 +33,7 @@ class PushHandler:
 		self._pushdir = self.config.get_pushdir()
 		self._apn = self.config.get_apn()
 		self._apn_nicename = self.config.get_apn_nicename()
-		self._incoming = '/opt/fmms/LAST_INCOMING'
+		self._incoming = '/home/user/.fmms/temp/LAST_INCOMING'
 		
 		if not os.path.isdir(self._mmsdir):
 			print "creating dir", self._mmsdir
